pub struct ParallelGradientComputer { /* private fields */ }Expand description
Parallel gradient computer using SciRS2-Core
Implementations
Sourceimpl ParallelGradientComputer
impl ParallelGradientComputer
Sourcepub fn with_config(config: ParallelConfig) -> Self
pub fn with_config(config: ParallelConfig) -> Self
Create with custom configuration
Sourcepub fn set_config(&mut self, config: ParallelConfig)
pub fn set_config(&mut self, config: ParallelConfig)
Set configuration
Sourcepub fn config(&self) -> &ParallelConfig
pub fn config(&self) -> &ParallelConfig
Get current configuration
Sourcepub fn stats(&self) -> &ParallelStats
pub fn stats(&self) -> &ParallelStats
Get statistics
Sourcepub fn reset_stats(&mut self)
pub fn reset_stats(&mut self)
Reset statistics
Sourcepub fn should_parallelize(&self, tensor_size: usize) -> bool
pub fn should_parallelize(&self, tensor_size: usize) -> bool
Check if a tensor should be processed in parallel
Sourcepub fn compute_optimal_chunk_size(&self, tensor_size: usize) -> usize
pub fn compute_optimal_chunk_size(&self, tensor_size: usize) -> usize
Compute optimal chunk size for a given tensor
Sourcepub fn compute_gradients_parallel<T>(
&mut self,
data: &[T],
) -> AutogradResult<Vec<T>>
pub fn compute_gradients_parallel<T>( &mut self, data: &[T], ) -> AutogradResult<Vec<T>>
Compute gradients in parallel for multiple tensors
This uses SciRS2-Core’s parallel operations to distribute gradient computation across multiple CPU cores with optimal work distribution.
Sourcepub fn parallel_element_wise_op<T, F>(
&mut self,
data: &[T],
op: F,
) -> AutogradResult<Vec<T>>
pub fn parallel_element_wise_op<T, F>( &mut self, data: &[T], op: F, ) -> AutogradResult<Vec<T>>
Apply a parallel operation to gradient data
This demonstrates integration with scirs2-core’s parallel_ops for element-wise operations on gradient tensors.
Sourcepub fn compute_with_intelligent_chunking<T>(
&mut self,
data: &[T],
grad_fn: impl Fn(&T) -> T + Send + Sync,
) -> AutogradResult<Vec<T>>
pub fn compute_with_intelligent_chunking<T>( &mut self, data: &[T], grad_fn: impl Fn(&T) -> T + Send + Sync, ) -> AutogradResult<Vec<T>>
Compute gradients using SciRS2’s intelligent chunking
This integrates with SciRS2-Core’s automatic performance optimization through intelligent chunking strategies.
Sourcepub fn report_performance(&self) -> String
pub fn report_performance(&self) -> String
Report current performance statistics